#!/bin/sh
#
# Program: MQWhat
#
# Output MQ related information.
#
# @author Roger Lacroix, Capitalware Inc.
# @return 0 for ok
# @version 1.2.0
# @license Apache 2 License
#
echo "MQWhat v1.2.0 by Capitalware Inc."
echo "(c) Copyright Capitalware Inc. 2009. All rights reserved."
#
CLASSPATH=
CMD_LocalClients=
CMD_Server=
CMD_SDK=
CMD_JAVA=
CMD_Samples=
CMD_Explorer=
CMD_GSK32=
CMD_GSK64=
Explorer_Output=
tempfile=mqwhat.temp.txt
#
# Which OS are we running on?
#
case `uname` in 
Linux)

    export MQ_PATH=/opt/mqm
    export MQ_JAVA_INSTALL_PATH=/opt/mqm/java
    export MQ_JAVA_DATA_PATH=/var/mqm
    export MQ_JAVA_LIB_PATH=/opt/mqm/java/lib
    L=$MQ_JAVA_INSTALL_PATH/lib
    
    CLASSPATH=$CLASSPATH:$L/com.ibm.mq.jar:$L/com.ibm.mqjms.jar:$L/com.ibm.mq.soap.jar:$L/commonservices.jar:$L/connector.jar:$L/dhbcore.jar:$L/fscontext.jar:$L/jms.jar:$L/jndi.jar:$L/jta.jar:$L/ldap.jar:$L/postcard.jar:$L/providerutil.jar:$L/rmm.jar
    export CLASSPATH=$CLASSPATH:/opt/mqm/samp/java/base:/opt/mqm/samp/java/jms

    rpm -q -a > $tempfile
    CMD_LocalClients=`cat $tempfile | grep MQSeriesClient`
    CMD_Server=`cat $tempfile | grep MQSeriesServer`
    CMD_SDK=`cat $tempfile | grep MQSeriesSDK`
    CMD_Java=`cat $tempfile | grep MQSeriesJava`
    CMD_Samples=`cat $tempfile | grep MQSeriesSamples`
    CMD_Explorer=`cat $tempfile | grep MQSeriesConfig`
    CMD_GSK32=`cat $tempfile | grep -i "gsk7bas-"`
    CMD_GSK64=`cat $tempfile | grep -i gsk7bas64`
    rm $tempfile

    if [ -z "$CMD_Explorer" ] ; then
       Explorer_Output="Explorer            = Not Installed"
    else
       Explorer_Output="Explorer            = Installed"
    fi

    ;; 

HP-UX)
    export MQ_PATH=/opt/mqm
    export MQ_JAVA_INSTALL_PATH=/opt/mqm/java
    export MQ_JAVA_LIB_PATH=/opt/mqm/java/lib
    export MQ_JAVA_DATA_PATH=/var/mqm
    L=$MQ_JAVA_INSTALL_PATH/lib

    CLASSPATH=$CLASSPATH:$L/com.ibm.mq.jar:$L/com.ibm.mqjms.jar:$L/com.ibm.mq.soap.jar:$L/commonservices.jar:$L/connector.jar:$L/dhbcore.jar:$L/fscontext.jar:$L/jms.jar:$L/jndi.jar:$L/jta.jar:$L/ldap.jar:$L/postcard.jar:$L/providerutil.jar:$L/rmm.jar
    export CLASSPATH=$CLASSPATH:/opt/mqm/samp/java/base:/opt/mqm/samp/java/jms

    /usr/sbin/swlist -l fileset > $tempfile
    CMD_LocalClients=`cat $tempfile | grep MQSERIES.MQM-CL-HPUX`
    CMD_Server=`cat $tempfile | grep MQSERIES.MQM-SERVER`
    CMD_SDK=`cat $tempfile | grep MQSERIES.MQM-BASE`
    CMD_Java=`cat $tempfile | grep MQSERIES.MQM-JAVA`
    CMD_Samples=`cat $tempfile | grep MQSERIES.MQM-SAMPLES`
    CMD_GSK32=`cat $tempfile | grep -i gsk`
    CMD_GSK64=`cat $tempfile | grep -i gsk7bas64`
    rm $tempfile

    ;;

SunOS)
    MQ_PATH=/opt/mqm
    export MQ_PATH
    MQ_JAVA_INSTALL_PATH=/opt/mqm/java
    export MQ_JAVA_INSTALL_PATH   
    MQ_JAVA_LIB_PATH=/opt/mqm/java/lib
    export MQ_JAVA_LIB_PATH
    MQ_JAVA_DATA_PATH=/var/mqm
    export MQ_JAVA_DATA_PATH
    L=$MQ_JAVA_INSTALL_PATH/lib

    CLASSPATH=$CLASSPATH:$L/com.ibm.mq.jar:$L/com.ibm.mqjms.jar:$L/com.ibm.mq.soap.jar:$L/commonservices.jar:$L/connector.jar:$L/dhbcore.jar:$L/fscontext.jar:$L/jms.jar:$L/jndi.jar:$L/jta.jar:$L/ldap.jar:$L/postcard.jar:$L/providerutil.jar:$L/rmm.jar
    CLASSPATH=$CLASSPATH:/opt/mqm/samp/java/base:/opt/mqm/samp/java/jms
    export CLASSPATH

    /usr/bin/pkgparam mqm CLASSES  > $tempfile 2>&1
    CMD_LocalClients=`cat $tempfile | grep -i client`
    CMD_Server=`cat $tempfile | grep -i server`
    CMD_Samples=`cat $tempfile | grep -i samples`
    CMD_Java=`cat $tempfile | grep -i java`

    if [ -d $MQ_PATH/inc ] ; then
       CMD_SDK="yes"
    fi

    rm $tempfile

    tempGSKfile=mqwhat.gsk.txt
    /usr/bin/pkginfo gsk7bas > $tempGSKfile 2>&1
    CMD_GSK32=`cat $tempGSKfile | grep application`
    /usr/bin/pkginfo gsk7bas64 > $tempGSKfile 2>&1
    CMD_GSK64=`cat $tempGSKfile | grep application`
    rm $tempGSKfile

    ;;

AIX)
    export MQ_PATH=/usr/mqm
    export MQ_JAVA_INSTALL_PATH=/usr/mqm/java
    export MQ_JAVA_LIB_PATH=/usr/mqm/java/lib
    export MQ_JAVA_DATA_PATH=/var/mqm
    L=$MQ_JAVA_INSTALL_PATH/lib

    CLASSPATH=$CLASSPATH:$L/com.ibm.mq.jar:$L/com.ibm.mqjms.jar:$L/com.ibm.mq.soap.jar:$L/commonservices.jar:$L/connector.jar:$L/dhbcore.jar:$L/fscontext.jar:$L/jms.jar:$L/jndi.jar:$L/jta.jar:$L/ldap.jar:$L/postcard.jar:$L/providerutil.jar:$L/rmm.jar
    export CLASSPATH=$CLASSPATH:/usr/mqm/samp/java/base:/usr/mqm/samp/java/jms 

    lslpp -l "mq*" "gsk*" > $tempfile 
    CMD_LocalClients=`cat $tempfile | grep mqm.client.rte`
    CMD_Server=`cat $tempfile | grep mqm.server.rte`
    CMD_SDK=`cat $tempfile | grep mqm.base.sdk`
    CMD_Samples=`cat $tempfile | grep mqm.base.samples`
    CMD_Java=`cat $tempfile | grep mqm.java.rte`
    CMD_GSK32=`cat $tempfile | grep gsksa.rte`
    CMD_GSK64=`cat $tempfile | grep gsksa.rte`
    rm $tempfile

    ;;
    
*) 
    echo "Unknown platform: MQWhat may not work on this platform"
    exit
    ;;
esac
#
# Extract information
#
if (dspmqver -p 1 -f 1 -b | grep -i Client > /dev/null) ; then
   ProductTypeValue=Client
else
   ProductTypeValue=Server
fi

VRMF=`dspmqver -p 1 -f 2 -b`
MQServerVersion=`dspmqver -p 1 -f 2 -b | cut -d. -f1`
MQServerRelease=`dspmqver -p 1 -f 2 -b | cut -d. -f2`

if [ -z "$CMD_Server" ] ; then
   Server="Not Installed"
else
   Server="Installed"
fi

if [ -z "$CMD_LocalClients" ] ; then
   LocalClients="Not Installed"
else
   LocalClients="Installed"
fi

if [ -z "$CMD_SDK" ] ; then
   Development="Not Installed"
else
   Development="Installed"
fi

if [ -z "$CMD_Java" ] ; then
   mqjava="Not Installed"
else
   mqjava="Installed"
fi

if [ -z "$CMD_Samples" ] ; then
   mqsamples="Not Installed"
else
   mqsamples="Installed"
fi

if [ -z "$CMD_GSK32" ] ; then
   gsk32="Not Installed"
else
   gsk32="Installed"
fi

if [ -z "$CMD_GSK64" ] ; then
   gsk64="Not Installed"
else
   gsk64="Installed"
fi

maint=`dspmqver -p 1 -f 2 -b | cut -c 5-7`

if ([ "$maint" = "0.0" ]) ; then
 maint="None"
fi

#
# Output the information
#
echo "+-----------------------------------------------------+"
echo "| Currently Installed Version Information             |"
echo "+-----------------------------------------------------+"
echo "ProductType      = "$ProductTypeValue
echo "VRMF             = "$VRMF
echo "MQServerVersion  = "$MQServerVersion
echo "MQServerRelease  = "$MQServerRelease
echo "Operating System = "`uname -a`

echo "+-----------------------------------------------------+"
echo "| Currently Installed Components                      |"
echo "+-----------------------------------------------------+"
echo "Server              = "$Server
echo "Local Clients       = "$LocalClients
echo "Development Toolkit = "$Development
echo "Java                = "$mqjava
echo "Samples             = "$mqsamples
if [ ! -z "$Explorer_Output" ] ; then
   echo "$Explorer_Output"
fi

echo "GSK 32-bit          = "$gsk32
echo "GSK 64-bit          = "$gsk64

echo "+-----------------------------------------------------+"
echo "| Currently Applied Maintenance                       |"
echo "+-----------------------------------------------------+"
echo "Maintenance = "$maint

echo "+-----------------------------------------------------+"
echo "| State of Queue Managers                             |"
echo "+-----------------------------------------------------+"
echo "Default QMgr Name                           Status"
echo "------- ---------                           ------"

dspmq -s -o default | while read line 
do
  qmgr=`echo $line | cut -d '(' -f2,3 | cut -d ')' -f1`
  qmgr=$qmgr"------------------------------------------------"
  qmgr=`echo $qmgr | cut -c 1-35 | tr '-' ' '`
  status=`echo $line | cut -d '(' -f3 | cut -d ')' -f1` 
  defaultvalue=`echo $line | cut -d '(' -f4 | cut -d ')' -f1`
  if ([ "$defaultvalue" = "no" ]) ; then
     defaultQMgr="       "
  else
     defaultQMgr="   *   "
  fi

  echo "$defaultQMgr $qmgr $status"
done

echo "+-----------------------------------------------------+"
echo "| Individual Queue Manager Information                |"
echo "+-----------------------------------------------------+"

dspmq  | cut -d '(' -f2,3 | cut -d ')' -f1  | while read qmgr
do
   echo "Queue Manager Name: $qmgr"
   echo "  Default="`dspmq -m $qmgr -o default | cut -d '(' -f3 | cut -d ')' -f1`

   echo "  Listeners:"
   echo "dis listener(*)" | runmqsc -e $qmgr | grep LISTENER | cut -d '(' -f2,3 | cut -d ')' -f1 | while read listener
   do
      echo "    Name=$listener"

      status=`echo "dis lsstatus('$listener') status" | runmqsc -e $qmgr | grep STATUS`
      echo "    Status="$status

      echo "dis listener('$listener') all" | runmqsc -e $qmgr > $tempfile
      echo "    IP Address="`grep "IPADDR" $tempfile | cut -d '(' -f2,3 | cut -d ')' -f1`
      echo "    Port="`grep "PORT" $tempfile | cut -d '(' -f3 | cut -d ')' -f1`
      echo "    Type="`grep "TRPTYPE" $tempfile | cut -d '(' -f2,3 | cut -d ')' -f1`
      echo "    Control="`grep "CONTROL" $tempfile | cut -d '(' -f3 | cut -d ')' -f1`
      echo "    --------------------"
   done

   echo "  Logging:"
   convertedqmgr=`echo $qmgr | tr '.' '!' | tr '/' '&'`
   echo "   "`grep "LogType" $MQ_JAVA_DATA_PATH/qmgrs/$convertedqmgr/qm.ini`
   echo "   "`grep "LogPrimaryFiles" $MQ_JAVA_DATA_PATH/qmgrs/$convertedqmgr/qm.ini`
   echo "   "`grep "LogSecondaryFiles" $MQ_JAVA_DATA_PATH/qmgrs/$convertedqmgr/qm.ini`
   echo "   "`grep "LogPath" $MQ_JAVA_DATA_PATH/qmgrs/$convertedqmgr/qm.ini`
   echo "   "`grep "LogBufferPages" $MQ_JAVA_DATA_PATH/qmgrs/$convertedqmgr/qm.ini`
   echo "   "`grep "LogFilePages" $MQ_JAVA_DATA_PATH/qmgrs/$convertedqmgr/qm.ini`
   echo "    --------------------"

   echo "  Services:"
   echo "dis service(*)" | runmqsc -e $qmgr | grep SERVICE | cut -d '(' -f2,3 | cut -d ')' -f1 | while read service
   do
      echo "    Name=$service"

      status=`echo "dis svstatus('$service') status" | runmqsc -e $qmgr | grep STATUS`
      echo "    Status="$status

      echo "dis service('$service') all" | runmqsc -e $qmgr > $tempfile
      echo "    Control="`grep "CONTROL" $tempfile | cut -d '(' -f3 | cut -d ')' -f1`
      echo "    Service Type="`grep "SERVTYPE" $tempfile | cut -d '(' -f2,3 | cut -d ')' -f1`
      echo "    --------------------"
   done
done

if [ -f $tempfile ]; then
   rm $tempfile
fi

exit
